# OctoBot-Tentacles-Manager [1.0.2](https://github.com/Drakkar-Software/OctoBot-Tentacles-Manager/tree/master/CHANGELOG.md)
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Tentacles-Manager.svg)](https://pypi.python.org/pypi/OctoBot-Tentacles-Manager/)
[![Downloads](https://pepy.tech/badge/OctoBot-Tentacles-Manager/month)](https://pepy.tech/project/OctoBot-Tentacles-Manager)
[![Build Status](https://api.travis-ci.org/Drakkar-Software/OctoBot-Tentacles-Manager.svg?branch=master)](https://travis-ci.org/Drakkar-Software/OctoBot-Tentacles-Manager) 
[![Build status](https://ci.appveyor.com/api/projects/status/c7afc4o5bxt84po9?svg=true)](https://ci.appveyor.com/project/Herklos/octobot-tentacles-manager)


A module manager for your [OctoBot](https://github.com/Drakkar-Software/OctoBot) ! 


## Usage
- Install [OctoBot](https://github.com/Drakkar-Software/OctoBot)

- Use CLI interface : 

``` {.sourceCode .bash}
$ python3 start.py -p install all
```
OR
``` {.sourceCode .bash}
$ ./OctoBot -p install all
```

- Use your OctoBot web interface at **'Tentacles'**
